==> jc-1.4.0.tar.gz: java/util/logging/LoggingPermission.h <==
// public final class java.util.logging.LoggingPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 4fb3a1cbd7a43880 java_util_logging_LoggingPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_util_logging_LoggingPermission_H_
#define _JC_java_util_logging_LoggingPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_logging_LoggingPermission$sub_refs	_jc_java_util_logging_LoggingPermission$sub_refs;
typedef struct _jc_java_util_logging_LoggingPermission$sub_nonrefs	_jc_java_util_logging_LoggingPermission$sub_nonrefs;
typedef struct _jc_java_util_logging_LoggingPermission$refs	_jc_java_util_logging_LoggingPermission$refs;
typedef struct _jc_java_util_logging_LoggingPermission$nonrefs	_jc_java_util_logging_LoggingPermission$nonrefs;
typedef struct _jc_java_util_logging_LoggingPermission$object	_jc_java_util_logging_LoggingPermission$object;

typedef const struct _jc_java_util_logging_LoggingPermission$vmethods	_jc_java_util_logging_LoggingPermission$vmethods;
typedef const struct _jc_java_util_logging_LoggingPermission$vtable	_jc_java_util_logging_LoggingPermission$vtable;
typedef const struct _jc_java_util_logging_LoggingPermission$vtype	_jc_java_util_logging_LoggingPermission$vtype;

// Constructors
extern void _jc_java_util_logging_LoggingPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_util_logging_LoggingPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_util_logging_LoggingPermission$vmethods {
};

// Vtable
struct _jc_java_util_logging_LoggingPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_util_logging_LoggingPermission$vmethods	java_util_logging_LoggingPermission;
};

// Vtype
struct _jc_java_util_logging_LoggingPermission$vtype {
	_jc_type			type;
	_jc_java_util_logging_LoggingPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_LoggingPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_LoggingPermission$refs {
    _jc_java_util_logging_LoggingPermission$sub_refs	java_util_logging_LoggingPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_LoggingPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_LoggingPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_util_logging_LoggingPermission$sub_nonrefs	java_util_logging_LoggingPermission;
};

// Object instance structure
struct _jc_java_util_logging_LoggingPermission$object {
	_jc_java_util_logging_LoggingPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_LoggingPermission$vtype	*vtype;
	_jc_java_util_logging_LoggingPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_LoggingPermission$vtype _jc_java_util_logging_LoggingPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_LoggingPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_LoggingPermission$class_object;

#endif	/* _JC_java_util_logging_LoggingPermission_H_ */

==> jc-1.4.6.tar.gz: java/util/logging/LoggingPermission.h <==
// public final class java.util.logging.LoggingPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 4fb3a1cbd7a43880 java_util_logging_LoggingPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_util_logging_LoggingPermission_H_
#define _JC_java_util_logging_LoggingPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_logging_LoggingPermission$sub_refs	_jc_java_util_logging_LoggingPermission$sub_refs;
typedef struct _jc_java_util_logging_LoggingPermission$sub_nonrefs	_jc_java_util_logging_LoggingPermission$sub_nonrefs;
typedef struct _jc_java_util_logging_LoggingPermission$refs	_jc_java_util_logging_LoggingPermission$refs;
typedef struct _jc_java_util_logging_LoggingPermission$nonrefs	_jc_java_util_logging_LoggingPermission$nonrefs;
typedef struct _jc_java_util_logging_LoggingPermission$object	_jc_java_util_logging_LoggingPermission$object;

typedef const struct _jc_java_util_logging_LoggingPermission$vmethods	_jc_java_util_logging_LoggingPermission$vmethods;
typedef const struct _jc_java_util_logging_LoggingPermission$vtable	_jc_java_util_logging_LoggingPermission$vtable;
typedef const struct _jc_java_util_logging_LoggingPermission$vtype	_jc_java_util_logging_LoggingPermission$vtype;

// Constructors
extern void _jc_java_util_logging_LoggingPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_util_logging_LoggingPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_logging_LoggingPermission$vmethods {
};

// Vtable
struct _jc_java_util_logging_LoggingPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_util_logging_LoggingPermission$vmethods	java_util_logging_LoggingPermission;
};

// Vtype
struct _jc_java_util_logging_LoggingPermission$vtype {
	_jc_type			type;
	_jc_java_util_logging_LoggingPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_LoggingPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_LoggingPermission$refs {
    _jc_java_util_logging_LoggingPermission$sub_refs	java_util_logging_LoggingPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_LoggingPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_LoggingPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_util_logging_LoggingPermission$sub_nonrefs	java_util_logging_LoggingPermission;
};

// Object instance structure
struct _jc_java_util_logging_LoggingPermission$object {
	_jc_java_util_logging_LoggingPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_LoggingPermission$vtype	*vtype;
	_jc_java_util_logging_LoggingPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_LoggingPermission$vtype _jc_java_util_logging_LoggingPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_LoggingPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_LoggingPermission$class_object;

#endif	/* _JC_java_util_logging_LoggingPermission_H_ */
